import React from 'react';
import { configure, shallow, render, mount } from 'enzyme';
import Adapter from 'enzyme-adapter-react-15.4';
import sinon from 'sinon';
import AutoComplete from '../src/component/AutoComplete';
import KEY_CODE from '../src/KEY_CODE';

configure({ adapter: new Adapter() });

const dataSource = [
  'HYPER Advertiser',
  'HYPER Web Analytics',
  'HYPER Video Analytics',
  'HYPER DMP',
  'HYPER Ad Serving',
  'HYPER Data Discovery'
];

const placeholder = 'Product Name';

const setup = (props) => {
  const dom = <AutoComplete {...props} />;
  const wrapper = shallow(dom);
  const staticRender = render(dom);
  const fullRender = mount(dom);
  return {
    props,
    wrapper,
    staticRender,
    fullRender
  };
};


describe('AutoComplete Test', () => {
  it('Should output a AutoCompleteItem', () => {
    const className = 'test-class';
    const onSelect = sinon.spy();
    const onChange = sinon.spy();
    const { fullRender } = setup({
      className,
      dataSource,
      placeholder,
      onSelect,
      onChange
    });
    expect(fullRender.find('.auto-complete-wrap').hasClass(className)).toBe(true);
    expect(fullRender.find('.form-control').getDOMNode().placeholder).toBe(placeholder);
    fullRender.find('.form-control').simulate('change', { target: { value: 'DMP' } });
    expect(onChange.calledOnce).toBe(true);
    expect(fullRender.find('.auto-complete-content').hasClass('show')).toBe(true);
    expect(fullRender.find('.auto-complete-item label').length).toBe(1);
    const firstItemText = fullRender.find('.auto-complete-item label').first().text();
    expect(firstItemText).toBe('HYPER DMP');
    fullRender.find('.auto-complete-item').first().simulate('click');
    expect(onSelect.calledOnce).toBe(true);
    expect(fullRender.find('.form-control').getDOMNode().value).toBe(firstItemText);
  });

  it('Test autoDomClosePanel', () => {
    const fullRender = mount(
      <AutoComplete
        dataSource={dataSource}
      />
    );
    fullRender.find('.form-control').simulate('focus');
    fullRender.find('.form-control').simulate('change', { target: { value: 'DMP' } });
    fullRender.find('.form-control').simulate('change', { target: { value: '' } });
    expect(fullRender.find('.auto-complete-content').hasClass('show')).toBe(false);
  });

  it('Test KeyDown Event ESC', () => {
    const fullRender = mount(
      <AutoComplete
        dataSource={dataSource}
      />
    );
    fullRender.find('.form-control').simulate('focus');
    fullRender.find('.form-control').simulate('change', { target: { value: 'DMP' } });
    fullRender.find('.form-control').simulate('keyDown', { keyCode: KEY_CODE.ESC });
    expect(fullRender.find('.auto-complete-content').hasClass('show')).toBe(false);
  });

  it('Test KeyDown Event DOWN', () => {
    const fullRender = mount(
      <AutoComplete
        dataSource={dataSource}
      />
    );
    fullRender.find('.form-control').simulate('focus');
    fullRender.find('.form-control').simulate('change', { target: { value: 'DMP' } });
    fullRender.find('.form-control').simulate('keyDown', { keyCode: KEY_CODE.DOWN });
    expect(fullRender.find('.auto-complete-item label').text())
      .toBe(document.activeElement.querySelector('label').innerHTML);
  });

  it('AutoComplete be disabled', () => {
    const disabled = true;
    const { fullRender } = setup({
      disabled
    });
    expect(fullRender.find('.form-control').getDOMNode().disabled).toBe(disabled);
  });
});

