import React from 'react';
import { configure, shallow, render, mount } from 'enzyme';
import Adapter from 'enzyme-adapter-react-15.4';

import sinon from 'sinon';
import AutoCompleteItem from '../src/component/AutoCompleteItem';
import KEY_CODE from '../src/KEY_CODE';

configure({ adapter: new Adapter() });

const setup = (props) => {
  const dom = <AutoCompleteItem {...props} />;
  const wrapper = shallow(dom);
  const staticRender = render(dom);
  const fullRender = mount(dom);
  return {
    props,
    wrapper,
    staticRender,
    fullRender
  };
};


describe('AutoCompleteItem Test', () => {
  it('Should output a AutoCompleteItem', () => {
    const text = 'test';
    const title = 'test_title';
    const onClick = sinon.spy();
    const onClose = sinon.spy();
    const onKeyDown = sinon.spy();
    const { fullRender } = setup({
      text,
      title,
      onClick,
      onClose,
      onKeyDown
    });
    expect(fullRender.find('.text').text()).toBe(text);
  });

  it('Should called Callback', () => {
    const text = 'test';
    const title = 'test_title';
    const onClick = sinon.spy();
    const onClose = sinon.spy();
    const onKeyDown = sinon.spy();
    const { fullRender } = setup({
      text,
      title,
      onClick,
      onClose,
      onKeyDown
    });

    fullRender.simulate('click');
    expect(onClick.calledOnce).toBe(true);
    fullRender.simulate('keyDown', { keyCode: KEY_CODE.ENTER });
    expect(onClick.calledTwice).toBe(true);
    fullRender.simulate('keyDown', { keyCode: KEY_CODE.ESC });
    expect(onClose.calledOnce).toBe(true);
    fullRender.simulate('keyDown', { keyCode: KEY_CODE.TAB });
    expect(onClose.calledTwice).toBe(true);
    fullRender.simulate('keyDown', { keyCode: KEY_CODE.UP });
    fullRender.simulate('keyDown', { keyCode: KEY_CODE.DOWN });

  });
});

